<?php
/**
 * Initialize social share
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package epic-social-share
 */

namespace EPIC\SS;

/**
 * Class Init
 *
 * @package EPIC\SS
 */
class Ss {

	/**
	 * Singleton initialization
	 *
	 * @var Ss
	 */
	private static $instance;

	/**
	 * Post ID
	 *
	 * @var Int
	 */
	private $post_id;

	/**
	 * Hold instance of object
	 *
	 * @var Object
	 */
	private $object;

	/**
	 * Homepage flag
	 *
	 * @var bool
	 */
	private $is_home;

	/**
	 * Get instance of social share
	 *
	 * @return Ss
	 */
	public static function get_instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Init constructor
	 */
	private function __construct() {
		$this->hook();

		$this->object['customizer'] = new Ss_Customizer();
	}

	/**
	 * Setup hook
	 */
	public function hook() {
		add_filter( 'the_content', array( $this, 'share_content' ) );
		add_filter( 'wp_footer', array( $this, 'share_outside_content' ) );
		add_action( 'plugins_loaded', array( $this, 'load_plugin_textdomain' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'load_assets' ) );
		add_filter( 'epic_plugin_list', array( $this, 'plugin_list' ) );

		add_filter( 'epic_social_share_content_post_type', array( $this, 'content_post_type' ) );
		add_filter( 'epic_social_share_side_post_type', array( $this, 'side_post_type' ) );
		add_filter( 'epic_social_share_mobile_post_type', array( $this, 'mobile_post_type' ) );

		// widget
		add_action( 'widgets_init', array( $this, 'load_widget' ) );

		// elementor
		add_action( 'elementor/init', array( $this, 'register_group' ) );
		add_action( 'elementor/widgets/widgets_registered', array( $this, 'register_module' ) );

		epic_activation_hook( EPIC_SS_FILE );

		Ss_Wpbakery::get_instance();

		$this->set_home_flag();
	}

	/**
	 * Register Elementor module
	 *
	 * @param $widgets_manager
	 */
	public function register_module( $widgets_manager ) {
		$widgets_manager->register_widget_type( new Ss_Elementor() );
	}

	/**
	 * Register Elementor group
	 */
	public function register_group() {
		\Elementor\Plugin::$instance->elements_manager->add_category( 'epic-ss-element', [ 'title' => esc_html__( 'Epic Social Share', 'epic-ss' ) ], 1 );
	}

	/**
	 * Load plugin assets
	 */
	public function load_assets() {
		wp_enqueue_style( 'font-awesome', EPIC_SS_URL . '/assets/fonts/font-awesome/font-awesome.css', null, EPIC_SS_VERSION );
		wp_enqueue_style( 'epic-social-share', EPIC_SS_URL . '/assets/css/social-share.css', null, EPIC_SS_VERSION );

		wp_enqueue_script( 'epic-social-share', EPIC_SS_URL . '/assets/js/social-share.js', array( 'jquery' ), EPIC_SS_VERSION, true );
		wp_enqueue_script( 'theia-sticky-sidebar', EPIC_SS_URL . '/assets/js/theia-sticky-sidebar.min.js', EPIC_SS_VERSION, true );
	}

	/**
	 * Set post ID
	 *
	 * @param $id
	 */
	public function set_post_id( $id ) {
		$this->post_id = $id;
	}

	/**
	 * Set home flag
	 *
	 * @param bool $flag
	 */
	public function set_home_flag( $flag = false ) {
		$this->is_home = $flag;
	}

	/**
	 * Content share post type
	 *
	 * @param $value
	 *
	 * @return mixed
	 */
	public function content_post_type( $value ) {
		$page = self::get_option( 'content_share_page', false );

		if ( $page ) {
			$value[] = 'page';
		}

		return $value;
	}

	/**
	 * Side post type
	 *
	 * @param $value
	 *
	 * @return mixed
	 */
	public function side_post_type( $value ) {
		$page = self::get_option( 'side_share_page', false );

		if ( $page ) {
			$value[] = 'page';
		}

		return $value;
	}

	/**
	 * Mobile post type
	 *
	 * @param $value
	 *
	 * @return mixed
	 */
	public function mobile_post_type( $value ) {
		$page = self::get_option( 'mobile_share_page', false );

		if ( $page ) {
			$value[] = 'page';
		}

		return $value;
	}

	/**
	 * Get saved option from customizer
	 *
	 * @param $setting
	 * @param null $default
	 *
	 * @return null
	 */
	public static function get_option( $setting, $default = null ) {
		$options = get_option( 'ss_option', array() );
		$value   = $default;

		if ( isset( $options[ $setting ] ) ) {
			$value = $options[ $setting ];
		}

		return $value;
	}

	/**
	 * Share content element handler
	 *
	 * @param $content
	 *
	 * @return string
	 */
	public function share_content( $content ) {
		$this->post_id = $this->post_id ? $this->post_id : get_the_ID();

		if ( is_singular( apply_filters( 'epic_social_share_content_post_type', array( 'post' ) ) ) ) {
			$position = self::get_option( 'content_share_position', 'top' );

			if ( in_array( $position, array( 'top', 'topbottom' ) ) ) {
				$content = $this->share_top( $content, $position, 'share_top' );
			}

			if ( in_array( $position, array( 'bottom', 'topbottom', 'floatbottom' ) ) ) {
				$content = $this->share_bottom( $content, $position, 'share_bottom' );
			}

			if ( in_array( $position, array( 'float', 'floatbottom' ) ) ) {
				$content = $this->share_float( $content, $position, 'share_float' );
			}
		}

		return $content;
	}

	/**
	 * Top share handler
	 *
	 * @param $content
	 *
	 * @return string
	 */
	public function share_top( $content, $position = null, $element = null ) {
		$type   = self::get_option( 'content_share_type_top', '1' );
		$style  = $this->share_top_style( $position, $element );
		$output = '';

		switch ( $type ) {
			case '1':
				$output = $this->share_type_1($position, $element);
				break;

			case '2':
				$output = $this->share_type_2($position, $element);
				break;
		}

		$output = apply_filters( 'epic_top_share_output', $output, $this->post_id );

		return
			'<div class="jeg_share_top_container">
				<div class="jeg_share_button ' . $style . ' clearfix">
					' . $output . '
				</div>
			</div>' . $content;
	}

    /**
     * @param null $position
     * @param null $element
     * @return mixed|void
     */
    public function share_top_style($position = null, $element = null){
        if ( self::get_option('override_top_icon_style', false) && $element === 'share_top' ){
            $style = self::get_option( 'top_content_share_style', 'colored' );
        }else {
            $style = self::get_option( 'content_share_style', 'colored' );
        }
        return apply_filters('epic_top_share_style', $style, $position, $element);
    }

	/**
	 * Bottom share handler
	 *
	 * @param $content
	 *
	 * @return string
	 */
	public function share_bottom( $content, $position = null, $element = null ) {
		$type   = self::get_option( 'content_share_type_bottom', '1' );
		$style  = $this->share_bottom_style( $position, $element );
		$output = '';

		switch ( $type ) {
			case '1':
				$output = $this->share_type_1($position, $element);
				break;

			case '2':
				$output = $this->share_type_2($position, $element);
				break;
		}

		$output = apply_filters( 'epic_bottom_share_output', $output, $this->post_id );

		return $content .
		       '<div class="jeg_share_bottom_container">
					<div class="jeg_share_button ' . $style . ' clearfix">
						' . $output . '
					</div>
				</div>';
	}

    /**
     * @param null $position
     * @param null $element
     * @return mixed|void
     */
    public function share_bottom_style($position = null, $element = null){
        if ( self::get_option('override_bottom_icon_style', false) && $element === 'share_bottom' ){
            $style = self::get_option( 'bottom_content_share_style', 'colored' );
        }else {
            $style = self::get_option( 'content_share_style', 'colored' );
        }
        return apply_filters('epic_bottom_share_style', $style, $position, $element);
    }

	/**
	 * Float share handler
	 *
	 * @param $content
	 *
	 * @return string
	 */
	public function share_float( $content, $position = null, $element = null ) {
		$type   = self::get_option( 'content_share_type_float', '1' );
		$style  = $this->share_bottom_style( $position, $element );
		$output = '';

		switch ( $type ) {
			case '1':
			case '2':
				$output = $this->share_float_type_1($position, $element);
				break;
		}

		$output = apply_filters( 'epic_float_share_output', $output, $this->post_id );

		return
			'<div class="jeg-entry-content with-share">
				<div class="jeg_share_button ' . $style . ' share-float jeg_sticky_share clearfixs share-normal">
					<div class="jeg_share_float_container">' . $output . '</div>
				</div>
				<div class="jeg-content-inner">' . $content . '</div>
			</div>';
	}

    /**
     * @param null $position
     * @param null $element
     * @return mixed|void
     */
    public function share_float_style($position = null, $element = null){
        if ( self::get_option('override_float_icon_style', false) && $element === 'share_float' ){
            $style = self::get_option( 'float_content_share_style', 'colored' );
        }else {
            $style = self::get_option( 'content_share_style', 'colored' );
        }
        return apply_filters('epic_float_share_style', $style, $position, $element);
    }

	/**
	 * Share outside element handler
	 */
	public function share_outside_content() {
		$this->post_id = $this->post_id ? $this->post_id : get_the_ID();

		if ( is_singular( apply_filters( 'epic_social_share_side_post_type', array( 'post' ) ) ) ) {
			echo '<div class="jeg_share_side_container">' . $this->share_side_output('share_side_output') . '</div>';
		}

		if ( is_singular( apply_filters( 'epic_social_share_mobile_post_type', array( 'post' ) ) ) ) {
			echo '<div class="jeg_share_mobile_container">' . $this->share_mobile_output('share_mobile_output') . '</div>';
		}
	}

	/**
	 * Share type 1 handler
	 *
	 * @return string
	 */
	public function share_type_1($position = null, $element = null) {
		$main_button      = $this->main_button($position, $element);
		$secondary_button = $this->secondary_button($position, $element);

		return
			'<div class="jeg_sharelist type-1">
				' . $main_button . $secondary_button . '
            </div>';
	}

	/**
	 * Share type 2 handler
	 *
	 * @return string
	 */
	public function share_type_2($position = null, $element = null) {
		$main_button      = $this->main_button_bottom($position, $element);
		$secondary_button = $this->secondary_button($position, $element);

		return
			'<div class="jeg_sharelist type-2">
                ' . $main_button . $secondary_button . '
            </div>';
	}

	/**
	 * Share float type 1 handler
	 *
	 * @return string
	 */
	public function share_float_type_1($position = null, $element = null) {
		$main_button      = $this->main_button($position, $element);
		$secondary_button = $this->secondary_button($position, $element);

		return
			'<div class="jeg_sharelist type-1">
                ' . $main_button . $secondary_button . '
            </div>';
	}

	/**
	 * Share side handler
	 *
	 * @return bool|string
	 */
	public function share_side_output($element = null) {
		$position = self::get_option( 'side_share_position', 'hide' );
		if ( 'hide' !== $position ) {
			$type   = self::get_option( 'side_share_type', '1' );
    		$style  = $this->share_side_style($position, $element);
			$output = '';

			switch ( $type ) {
				case '1':
				case '2':
					$output = $this->share_side_type_1($position, $element);
					break;
			}

			$output = apply_filters( 'epic_side_share_output', $output, $this->post_id );

			return
				'<div class="jeg_share_button ' . $position . ' ' . $style . ' clearfix">
					' . $output . '
				</div>';
		}

		return false;
	}

    /**
     * @param null $position
     * @param null $element
     * @return mixed|void
     */
	public function share_side_style($position = null, $element = null){
        if ( self::get_option('override_side_icon_style', false) && $element === 'share_side_output' ){
            $style = self::get_option( 'side_content_share_style', 'colored' );
        }else {
            $style = self::get_option( 'content_share_style', 'colored' );
        }
        return apply_filters('epic_side_share_style', $style, $position, $element);
    }

	/**
	 * Share side type 1 handler
	 *
	 * @return string
	 */
	public function share_side_type_1($position = null, $element = null) {
		$main_button      = $this->main_button($position, $element);
		$secondary_button = $this->secondary_button($position, $element);

		return
			'<div class="jeg_sharelist type-1">
                ' . $main_button . $secondary_button . '
            </div>';
	}

	/**
	 * Share mobile handler
	 *
	 * @return bool|string
	 */
	public function share_mobile_output($element = null) {
		if ( self::get_option( 'mobile_share_position', false ) ) {
			$output = apply_filters( 'epic_mobile_share_output', $this->share_mobile_type_1($element), $this->post_id );
    		$style  = $this->share_mobile_style(null, $element);

			return
				'<div class="jeg_share_button ' . $style . ' clearfix">
					' . $output . '
				</div>';
		}

		return false;
	}

    /**
     * @param null $position
     * @param null $element
     * @return mixed|void
     */
    public function share_mobile_style($position = null, $element = null){
        if ( self::get_option('override_mobile_icon_style', false) && $element === 'share_mobile_output' ){
            $style = self::get_option( 'mobile_content_share_style', 'colored' );
        }else {
            $style = self::get_option( 'content_share_style', 'colored' );
        }
        return apply_filters('epic_mobile_share_style', $style, $position, $element);
    }

	/**
	 * Share mobile type 1 handler
	 *
	 * @return string
	 */
	public function share_mobile_type_1($element = null) {
		$main_button      = $this->main_button(null, $element);
		$secondary_button = '';
		$shares           = $this->get_secondary_button( null, $element);

		if ( ! empty( $shares ) ) {
			foreach ( $shares as $share ) {
				$secondary_button .= $this->build_button( $share['social_share'] );
			}
		}

		return
			'<div class="jeg_sharelist type-1">
                ' . $main_button . $secondary_button . '
            </div>';
	}

	/**
	 * Build main button share
	 *
	 * @return mixed
	 */
	protected function main_button($position = null, $element = null) {
        $main_button = '';
		$shares      = $this->get_main_button($position, $element);

		if ( ! empty( $shares ) ) {
			foreach ( $shares as $share ) {
				$main_button .= $this->build_button( $share['social_share'], $share['social_text'] );
			}
		}

		return apply_filters( 'epic_single_share_main_button', $main_button, $this->post_id );
	}

	/**
	 * Build main button bottm share
	 *
	 * @return mixed
	 */
	protected function main_button_bottom($position = null, $element = null) {
		$main_button = '';
		$shares      = $this->get_main_button($position, $element);

		if ( ! empty( $shares ) ) {
			foreach ( $shares as $share ) {
				$main_button .= $this->build_bottom_button( $share['social_share'] );
			}
		}

		return apply_filters( 'epic_single_share_main_button_bottom', $main_button, $this->post_id );
	}

	/**
	 * Build secondary button share
	 *
	 * @return mixed
	 */
	protected function secondary_button($position = null, $element = null) {
		$secondary_button = '';
		$shares           = $this->get_secondary_button( $position, $element);

		if ( ! empty( $shares ) ) {
			foreach ( $shares as $share ) {
				$secondary_button .= $this->build_button( $share['social_share'] );
			}

			$secondary_button =
				'<div class="share-secondary">
                    ' . $secondary_button . '
                </div>
                <a href="#" class="jeg_btn-toggle">
                	<i class="fa fa-share"></i>
                </a>';
		}

		return apply_filters( 'epic_single_share_secondary_button', $secondary_button, $this->post_id );
	}

	/**
	 * Get secondary button share
	 *
	 * @return mixed
	 */
	public function get_secondary_button($position = null, $element = null) {
		$secondary_button = array(
			array( 'social_share' => 'googleplus' ),
			array( 'social_share' => 'linkedin' )
		);

		$secondary_button = self::get_option( 'share_secondary', $secondary_button );
        if ( self::get_option('override_side_icon', false) && $element === 'share_side_output' )  {
            $secondary_button = self::get_option('side_share_secondary', $secondary_button );
        }
        if ( self::get_option('override_mobile_icon', false) && $element === 'share_mobile_output' )  {
            $secondary_button = self::get_option('mobile_share_secondary', $secondary_button );
        }
        if ( self::get_option('override_top_icon', false) && $element === 'share_top' )  {
            $secondary_button = self::get_option('top_share_secondary', $secondary_button );
        }
        if ( self::get_option('override_bottom_icon', false) && $element === 'share_bottom' )  {
            $secondary_button = self::get_option('bottom_share_secondary', $secondary_button );
        }
        if ( self::get_option('override_float_icon', false) && $element === 'share_float' )  {
            $secondary_button = self::get_option('float_share_secondary', $secondary_button );
        }

		return apply_filters( 'epic_single_share_secondary_button_list', $secondary_button, $position, $element );
	}

	/**
	 * Get main button share
	 *
	 * @return mixed
	 */
	public function get_main_button($position = null, $element = null) {
		$main_button = array(
			array(
                'social_share' => 'facebook',
                'social_text'  => esc_html__( 'Share on Facebook', 'epic-ss' )
            ),
			array(
				'social_share' => 'twitter',
				'social_text'  => esc_html__( 'Share on Twitter', 'epic-ss' )
			),
			array(
				'social_share' => 'pinterest',
				'social_text'  => ''
			),
		);

		$main_button = self::get_option( 'share_main', $main_button );
        if ( self::get_option('override_side_icon', false) && $element === 'share_side_output' )  {
            $main_button = self::get_option('side_share_main', $main_button );
        }
        if ( self::get_option('override_mobile_icon', false) && $element === 'share_mobile_output' )  {
            $main_button = self::get_option('mobile_share_main', $main_button );
        }
        if ( self::get_option('override_top_icon', false) && $element === 'share_top' )  {
            $main_button = self::get_option('top_share_main', $main_button );
        }
        if ( self::get_option('override_bottom_icon', false) && $element === 'share_bottom' )  {
            $main_button = self::get_option('bottom_share_main', $main_button );
        }
        if ( self::get_option('override_float_icon', false) && $element === 'share_float' )  {
            $main_button = self::get_option('float_share_main', $main_button );
        }


		return apply_filters( 'epic_single_share_main_button_list', $main_button, $position, $element );
	}

	/**
	 * Build button share
	 *
	 * @param $social
	 * @param string $text
	 *
	 * @return string
	 */
	protected function build_button( $social, $text = '' ) {
		$button_url           = $this->get_social_share_url( $social, $this->post_id );
		$button_class         = $this->get_button_class( $social );
		$icon_class           = $this->get_icon_class( $social );
		$additional_attribute = '';

		if ( function_exists( 'pll__' ) ) {
			$text = pll__( $text );
		}

		if ( function_exists( 'icl_t' ) ) {
			$text = icl_t( 'epic-ss', $text, $text );
		}

		$expanded  = ! empty( $text ) ? "expanded" : "";
		$sharetext = ! empty( $text ) ? "<span>$text</span>" : '';

		if ( $social === 'whatsapp' ) {
			$additional_attribute .= ' data-action="share/whatsapp/share" ';
		}

		$button =
			'<a href="' . $button_url . '" rel="nofollow" ' . $additional_attribute . ' class="' . $button_class . ' ' . $expanded . '">
				<i class="' . $icon_class . '"></i>
				' . $sharetext . '
			</a>';

		return $button;
	}

	/**
	 * Build bottom button share
	 *
	 * @param $social
	 *
	 * @return string
	 */
	protected function build_bottom_button( $social ) {
		$total = 0;

		switch ( $social ) {
			case 'facebook' :
				$text = esc_html__( 'Share', 'epic-ss' );
				break;
			case 'twitter' :
				$text = esc_html__( 'Tweet', 'epic-ss' );
				break;
			case 'googleplus' :
				$text = esc_html__( 'Share', 'epic-ss' );
				break;
			case 'pinterest' :
				$text = esc_html__( 'Pin', 'epic-ss' );
				break;
			case 'stumbleupon' :
				$text = esc_html__( 'Share', 'epic-ss' );
				break;
			case 'linkedin' :
				$text = esc_html__( 'Share', 'epic-ss' );
				break;
			case 'vk' :
				$text = esc_html__( 'Share', 'epic-ss' );
				break;
			case 'line' :
				$text = esc_html__( 'Share', 'epic-ss' );
				break;
			case 'hatena' :
				$text = esc_html__( 'Bookmark', 'epic-ss' );
				break;
			case 'qrcode' :
				$text = esc_html__( 'Scan', 'epic-ss' );
				break;
			case 'whatsapp' :
				$text = esc_html__( 'Send', 'epic-ss' );
				break;
			case 'email' :
				$text = esc_html__( 'Send', 'epic-ss' );
				break;
			default :
				$text = esc_html__( 'Share', 'epic-ss' );
		}

		$button_url   = $this->get_social_share_url( $social, $this->post_id );
		$button_class = $this->get_button_class( $social );
		$icon_class   = $this->get_icon_class( $social );

		$counttext = $total > 0 ? '<span class="count">' . $total . '</span>' : '';
		$sharetext = ! empty( $text ) ? '<span>' . $text . ' ' . $counttext . '</span>' : '';
		$button    =
			'<a href="' . $button_url . '" rel="nofollow" class="' . $button_class . ' expanded">
				<i class="' . $icon_class . '"></i>
				' . $sharetext . '
			</a>';

		return $button;
	}

	/**
	 * Get social share url
	 *
	 * @param $social
	 * @param $post_id
	 *
	 * @return string
	 */
	public function get_social_share_url( $social, $post_id ) {
		$image     = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'full' );
		$image_url = $image ? $image[0] : '';
		$title     = self::get_share_title( $post_id );
		$url       = apply_filters( 'epic_get_permalink', epic_encode_url( $post_id ) );

		if ( $this->is_home ) {
			$image_url = get_site_icon_url();
			$title     = get_bloginfo( 'name' );
			$url       = apply_filters( 'epic_get_permalink', esc_url( home_url( '/' ) ) );
		}

		switch ( $social ) {
			case 'facebook' :
				$button_url = 'http://www.facebook.com/sharer.php?u=' . $url;
				break;
			case 'twitter' :
				$title      = $this->is_home ? get_bloginfo( 'name' ) : self::get_share_twitter_title( $post_id );
				$button_url = 'https://twitter.com/intent/tweet?text=' . $title . '&url=' . $url;
				break;
			case 'googleplus' :
				$button_url = 'https://plus.google.com/share?url=' . $url;
				break;
			case 'pinterest' :
				$button_url = 'https://www.pinterest.com/pin/create/bookmarklet/?pinFave=1&url=' . $url . '&media=' . $image_url . '&description=' . $title;
				break;
			case 'stumbleupon' :
				$button_url = 'http://www.stumbleupon.com/submit?url=' . $url . '&title=' . $title;
				break;
			case 'linkedin' :
				$button_url = 'https://www.linkedin.com/shareArticle?url=' . $url . '&title=' . $title;
				break;
			case 'reddit' :
				$button_url = 'https://reddit.com/submit?url=' . $url . '&title=' . $title;
				break;
			case 'tumblr' :
				$button_url = 'https://www.tumblr.com/widgets/share/tool?canonicalUrl=' . $url . '&title=' . $title;
				break;
			case 'buffer' :
				$button_url = 'https://buffer.com/add?text=' . $title . '&url=' . $url;
				break;
			case 'vk' :
				$button_url = 'http://vk.com/share.php?url=' . $url;
				break;
			case 'whatsapp' :
				$button_url = 'whatsapp://send?text=' . $title . '%0A' . $url;
				break;
			case 'wechat' :
				// wechat only able to share post using qrcode
				// $button_url = 'weixin://dl/posts/link?url=' . $url;
				$button_url = 'https://chart.googleapis.com/chart?chs=400x400&cht=qr&choe=UTF-8&chl=' . $url;
				break;
			case 'line' :
				$button_url = 'line://msg/text/' . $url;
				break;
			case 'hatena' :
				$button_url = 'http://b.hatena.ne.jp/bookmarklet?url=' . $url . '&btitle=' . $title;
				break;
			case 'qrcode' :
				$button_url = 'https://chart.googleapis.com/chart?chs=400x400&cht=qr&choe=UTF-8&chl=' . $url;
				break;
			case 'email' :
				$button_url = 'mailto:?subject=' . $title . '&amp;body=' . $url;
				break;
			default:
				$button_url = $url;
				break;
		}

		return $button_url;
	}

	/**
	 * Get share title
	 *
	 * @param $post_id
	 *
	 * @return string
	 */
	public static function get_share_title( $post_id ) {
		$title = get_the_title( $post_id );
		$title = html_entity_decode( $title, ENT_QUOTES, 'UTF-8' );
		$title = urlencode( $title );
		$title = str_replace( '#', '%23', $title );

		return esc_html( $title );
	}

	/**
	 * Get Twitter share title
	 *
	 * @param $post_id
	 *
	 * @return string
	 */
	public static function get_share_twitter_title( $post_id ) {
		$title = get_the_title( $post_id );

		$via = self::get_option( 'twitter_account', '' );
		if ( ! empty ( $via ) ) {
			$title = $title . " via @" . $via;
		}

		$title = html_entity_decode( $title, ENT_QUOTES, 'UTF-8' );
		$title = urlencode( $title );
		$title = str_replace( '#', '%23', $title );

		return esc_html( $title );
	}

	/**
	 * Get button class
	 *
	 * @param $social
	 *
	 * @return string
	 */
	protected function get_button_class( $social ) {
		switch ( $social ) {
			case 'facebook' :
				$button_class = 'jeg_btn-facebook';
				break;
			case 'twitter' :
				$button_class = 'jeg_btn-twitter';
				break;
			case 'googleplus' :
				$button_class = 'jeg_btn-google-plus';
				break;
			case 'pinterest' :
				$button_class = 'jeg_btn-pinterest';
				break;
			case 'instagram' :
				$button_class = 'jeg_btn-instagram';
				break;
			case 'stumbleupon' :
				$button_class = 'jeg_btn-stumbleupon';
				break;
			case 'linkedin' :
				$button_class = 'jeg_btn-linkedin';
				break;
			case 'reddit' :
				$button_class = 'jeg_btn-reddit';
				break;
			case 'tumblr' :
				$button_class = 'jeg_btn-tumbrl';
				break;
			case 'buffer' :
				$button_class = 'jeg_btn-buffer';
				break;
			case 'vk' :
				$button_class = 'jeg_btn-vk';
				break;
			case 'whatsapp' :
				$button_class = 'jeg_btn-whatsapp';
				break;
			case 'wechat' :
				$button_class = 'jeg_btn-wechat';
				break;
			case 'line' :
				$button_class = 'jeg_btn-line';
				break;
			case 'hatena' :
				$button_class = 'jeg_btn-hatena';
				break;
			case 'qrcode' :
				$button_class = 'jeg_btn-qrcode';
				break;
			case 'email' :
				$button_class = 'jeg_btn-email';
				break;
			default :
				$button_class = '';
				break;
		}

		return $button_class;
	}

	/**
	 * Get icon class
	 *
	 * @param $social
	 *
	 * @return string
	 */
	protected function get_icon_class( $social ) {
		switch ( $social ) {
			case 'facebook' :
				$icon_class = 'fa fa-facebook-official';
				break;
			case 'twitter' :
				$icon_class = 'fa fa-twitter';
				break;
			case 'googleplus' :
				$icon_class = 'fa fa-google-plus';
				break;
			case 'pinterest' :
				$icon_class = 'fa fa-pinterest';
				break;
			case 'stumbleupon' :
				$icon_class = 'fa fa-stumbleupon';
				break;
			case 'linkedin' :
				$icon_class = 'fa fa-linkedin';
				break;
			case 'reddit' :
				$icon_class = 'fa fa-reddit';
				break;
			case 'tumblr' :
				$icon_class = 'fa fa-tumblr';
				break;
			case 'buffer' :
				$icon_class = 'fa fa-buffer';
				break;
			case 'vk' :
				$icon_class = 'fa fa-vk';
				break;
			case 'whatsapp' :
				$icon_class = 'fa fa-whatsapp';
				break;
			case 'wechat' :
				$icon_class = 'fa fa-wechat';
				break;
			case 'line' :
				$icon_class = 'fa fa-line';
				break;
			case 'hatena' :
				$icon_class = 'fa fa-hatena';
				break;
			case 'qrcode' :
				$icon_class = 'fa fa-qrcode';
				break;
			case 'email' :
				$icon_class = 'fa fa-envelope';
				break;
			default:
				$icon_class = 'fa fa-' . $social;
				break;
		}

		return $icon_class;
	}

	/**
	 * Get plugin data
	 *
	 * @param $plugins
	 *
	 * @return array
	 */
	public function plugin_list( $plugins ) {
		$plugins[] = array(
			'id'      => EPIC_SS_PLUGIN_ID,
			'name'    => EPIC_SS_NAME,
			'slug'    => EPIC_SS,
			'version' => EPIC_SS_VERSION,
			'option'  => 'epic_social_share_license',
			'file'    => EPIC_SS_FILE,
		);

		return $plugins;
	}

	/**
	 * Plugin text domain
	 */
	public function load_plugin_textdomain() {
		load_plugin_textdomain( 'epic-ss', false, EPIC_SS_DIR . '/languages/' );
	}

	/**
	 * Get element option
	 *
	 * @return array
	 */
	public function element_option() {
		$options = array();

		$options[] = array(
			'type'        => 'dropdown',
			'param_name'  => 'type',
			'heading'     => esc_html__( 'Share Type', 'epic-ss' ),
			'description' => esc_html__( 'Choose the share type.', 'epic-ss' ),
			'default'     => '1',
			'value'       => array(
				'1' => esc_html__( 'Type 1', 'epic-ss' ),
				'2' => esc_html__( 'Type 2', 'epic-ss' )
			)
		);

		return $options;
	}

	/**
	 * Load share widget
	 */
	public function load_widget() {
		require_once EPIC_SS_DIR . 'includes/class/class-ss-widget.php';
		register_widget( 'Ss_Widget' );
	}
}
